import os
import requests
import tarfile

def read_channel_references(tv_dir="/etc/enigma2"):
    channel_references = set()
    for filename in os.listdir(tv_dir):
        if filename.endswith(".tv"):
            with open(os.path.join(tv_dir, filename), "r") as tv_file:
                for line in tv_file:
                    if line.startswith("#SERVICE"):
                        parts = line.split(":")
                        if len(parts) > 10:
                            reference = parts[10].strip()
                            channel_references.add(reference)
    return channel_references

def download_picons(url, dest="/tmp/picons.tar.gz"):
    response = requests.get(url, stream=True)
    if response.status_code == 200:
        with open(dest, "wb") as file:
            for chunk in response.iter_content(chunk_size=8192):
                file.write(chunk)
    else:
        raise Exception(f"Failed to download picons archive. Status code: {response.status_code}")

def extract_relevant_picons(picon_archive="/tmp/picons.tar.gz", channel_references=None, dest_dir="/hdd/picon"):
    if channel_references is None:
        channel_references = set()
    with tarfile.open(picon_archive, "r:gz") as tar:
        for member in tar.getmembers():
            if any(ref in member.name for ref in channel_references):
                member.name = os.path.basename(member.name)
                tar.extract(member, dest_dir)

def install_picons(url, destination):
    try:
        channel_references = read_channel_references()
        download_picons(url=url)
        extract_relevant_picons(channel_references=channel_references, dest_dir=destination)
    except Exception as e:
        raise e

