from Screens.MessageBox import MessageBox
from Plugins.Plugin import PluginDescriptor
from Components.ActionMap import ActionMap
from Components.config import config, ConfigSubsection, ConfigSelection, getConfigListEntry
from Components.Label import Label
from Components.ConfigList import ConfigListScreen
from Screens.Screen import Screen
from enigma import eTimer
import os
import gettext
from .install_picons import *

# Set up gettext for translations
def _(txt):
    t = gettext.dgettext("PiconInstaller", txt)
    if t == txt:
        t = gettext.gettext(txt)
    return t

# Determine the default picon location
def determine_default_picon_location():
    if os.path.exists("/media/hdd"):
        if not os.path.exists("/media/hdd/picon"):
            os.makedirs("/media/hdd/picon")
        return "/media/hdd/picon"
    elif os.path.exists("/media/usb"):
        if not os.path.exists("/media/usb/picon"):
            os.makedirs("/media/usb/picon")
        return "/media/usb/picon"
    else:
        return "/usr/share/enigma2/picon"

# Configuration section
config.plugins.piconinstaller = ConfigSubsection()
config.plugins.piconinstaller.picon_location = ConfigSelection(
    default=determine_default_picon_location(),
    choices=[
        ("/media/hdd/picon", _("HDD (/media/hdd/picon)")),
        ("/media/usb/picon", _("USB (/media/usb/picon)")),
        ("/usr/share/enigma2/picon", _("Internal Flash (/usr/share/enigma2/picon)"))
    ]
)

config.plugins.piconinstaller.picon_resolution = ConfigSelection(
    default="400x240",
    choices=[
        ("400x240", _("400x240 (picons400x240.tar.gz)")),
        ("220x132", _("220x132 (picons220x132.tar.gz)"))
    ]
)

class PiconInstallerScreen(Screen, ConfigListScreen):
    skin = """
        <screen name="PiconInstallerScreen" position="center,center" size="460,260" title="Picon Installer by acypaczom">
            <widget name="config" position="10,10" size="440,160" scrollbarMode="showOnDemand" />
            <widget name="status" position="10,180" size="440,50" font="Regular;20" />
            <eLabel position="10,210" size="440,1" backgroundColor="#ffffff" />
            <widget name="key_red" position="10,220" zPosition="2" size="220,40" valign="center" halign="center" font="Regular;20" transparent="1" />
            <widget name="key_green" position="230,220" zPosition="2" size="220,40" valign="center" halign="center" font="Regular;20" transparent="1" />
        </screen>"""

    def __init__(self, session, args=None):
        Screen.__init__(self, session)
        self.session = session

        self.list = [
            getConfigListEntry(_("Picon Location"), config.plugins.piconinstaller.picon_location),
            getConfigListEntry(_("Picon Resolution"), config.plugins.piconinstaller.picon_resolution)
        ]
        ConfigListScreen.__init__(self, self.list, session)

        self["actions"] = ActionMap(["SetupActions", "ColorActions"],
        {
            "ok": self.save_and_install,
            "cancel": self.close,
            "red": self.close,
            "green": self.save_and_install,
        }, -1)

        self["status"] = Label(_("Press OK to start installation."))
        self["key_red"] = Label(_("Cancel"))
        self["key_green"] = Label(_("Install"))

    def save_and_install(self):
        self.saveAll()
        self.install_picons()

    def install_picons(self):
        self["status"].setText(_("Installing picons, please wait..."))
        self.timer = eTimer()
        self.timer.callback.append(self.run_install)
        self.timer.start(100, True)

    def run_install(self):
        try:
            resolution = config.plugins.piconinstaller.picon_resolution.value
            picon_url = (
                "http://s4aupdater.one.pl/picons400x240.tar.gz"
                if resolution == "400x240"
                else "http://s4aupdater.one.pl/picons220x132.tar.gz"
            )
            install_picons(
                url=picon_url,
                destination=config.plugins.piconinstaller.picon_location.value
            )
            self["status"].setText(_("Picons installed successfully."))
        except Exception as e:
            self.session.open(MessageBox, _("An error occurred: %s") % str(e), MessageBox.TYPE_ERROR)

def main(session, **kwargs):
    session.open(PiconInstallerScreen)

def Plugins(**kwargs):
    return [PluginDescriptor(name=_("Zet71 Picon Installer by acypaczom"), description=_("Install Zet71 Picons "), where=PluginDescriptor.WHERE_PLUGINMENU, fnc=main)]
